import os
import sys

sys.path.insert(0, os.path.abspath('sample-0.0.0-py3.7.egg'))
extensions = ['sphinx.ext.autodoc']
